/* libxsvg - Render SVG documents using the Xr library
 *
 * Copyright  2002 USC/Information Sciences Institute
 *
 * Permission to use, copy, modify, distribute, and sell this software
 * and its documentation for any purpose is hereby granted without
 * fee, provided that the above copyright notice appear in all copies
 * and that both that copyright notice and this permission notice
 * appear in supporting documentation, and that the name of
 * Information Sciences Institute not be used in advertising or
 * publicity pertaining to distribution of the software without
 * specific, written prior permission.  Information Sciences Institute
 * makes no representations about the suitability of this software for
 * any purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * INFORMATION SCIENCES INSTITUTE DISCLAIMS ALL WARRANTIES WITH REGARD
 * TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL INFORMATION SCIENCES
 * INSTITUTE BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
 * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA
 * OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 * Author: Carl Worth <cworth@isi.edu>
 */

#ifndef XSVG_H
#define XSVG_H

#include <cairo.h>
#include <cairo-xlib.h>

#include <svg.h>

typedef enum xsvg_status {
    XSVG_STATUS_SUCCESS = SVG_STATUS_SUCCESS,
    XSVG_STATUS_NO_MEMORY = SVG_STATUS_NO_MEMORY,
    XSVG_STATUS_IO_ERROR = SVG_STATUS_IO_ERROR,
    XSVG_STATUS_FILE_NOT_FOUND = SVG_STATUS_FILE_NOT_FOUND,
    XSVG_STATUS_INVALID_VALUE = SVG_STATUS_INVALID_VALUE,
    XSVG_STATUS_INVALID_CALL = SVG_STATUS_INVALID_CALL,
    XSVG_STATUS_PARSE_ERROR = SVG_STATUS_PARSE_ERROR
} xsvg_status_t;

typedef struct xsvg xsvg_t;

xsvg_status_t
xsvg_create (xsvg_t **xsvg);

xsvg_status_t
xsvg_destroy (xsvg_t *xsvg);

xsvg_status_t
xsvg_parse_file (xsvg_t *xsvg, const char *file_name);

xsvg_status_t
xsvg_parse_buffer (xsvg_t *xsvg, const char *buf, size_t count);

xsvg_status_t
xsvg_parse_chunk_begin (xsvg_t *xsvg);

xsvg_status_t
xsvg_parse_chunk       (xsvg_t *xsvg, const char *buf, size_t count);

xsvg_status_t
xsvg_parse_chunk_end   (xsvg_t *xsvg);

xsvg_status_t
xsvg_render (xsvg_t *xsvg, cairo_t *xrs);

/* XXX: Ugh... this inconsistent interface needs to be cleaned up. */
xsvg_status_t
xsvg_set_viewport_dimension (xsvg_t *xsvg, unsigned int width, unsigned int height);

void
xsvg_get_size (xsvg_t *xsvg, int *width, int *height);

#endif
